# Sanic Babel - 0.1.3

Most of the codes are from [flask-babel][], and updated to match sanic.

Implements i18n and l10n support for Sanic.  This is based on the Python
[babel][] module as well as [pytz][] both of which are installed automatically
for you if you install this library.

# Documention

The latest documentation is available [here][docs].

[flask-babel]: http://github.com/mitsuhiko/flask-babel
[babel]: https://github.com/python-babel/babel
[pytz]: https://pypi.python.org/pypi/pytz/
[docs]: http://sanic-babel.readthedocs.io/
